Class: extension - LinkML Model

# Class: extension

a tag/value pair used to add non-model information to an entry

URI: linkml:Extension

## Children

- Annotation - a tag/value pair with the semantics of OWL Annotation

## Referenced by Class

- Extensible extensions 0..* Extension

## Attributes

### Own

- extension➞tag 1..1
  - Description: a tag associated with an extension
  - Range: Uriorcurie
- extension➞value 1..1
  - Description: the actual annotation
  - Range: String
- extensions 0..*
  - Description: a tag/text tuple attached to an arbitrary element
  - Range: Extension